@@ -1,7 +1,8 @@
 /*
  *  obexautofs.c: FUSE Filesystem to access OBEX with automount
+ *  This is just a wrapper. ObexFTP API does the real work.
  *
- *  Copyright (c) 2005 Christian W. Zuckschwerdt <zany@triq.net>
+ *  Copyright (c) 2003-2006 Christian W. Zuckschwerdt <zany@triq.net>
  *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the Free
@@ -18,10 +19,6 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *     
  */
-/*
- * Created at:    2005-09-22
- * This is just a wrapper. ObexFTP API does the real work.
- */
 
 /* strndup */
 #define _GNU_SOURCE
@@ -33,6 +30,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <inttypes.h>
 #include <string.h>
 #include <time.h>
 #include <fcntl.h>
@@ -97,7 +95,7 @@ static int discover_irda(void) { return -1; }
 
 static int discover_usb(void) { return -1; }
 
-static int discover_tty(char *port) { return -1; }
+static int discover_tty(char *UNUSED(port)) { return -1; }
 
 static int discover_bt(void)
 {
@@ -398,7 +396,7 @@ static int ofs_getattr(const char *path, struct stat *stbuf)
 	return 0;
 }
 
-static int ofs_readlink (const char *path, char *link, size_t size)
+static int ofs_readlink (const char *path, char *link, size_t UNUSED(size))
 {
 	connection_t *conn;
 
@@ -615,7 +613,7 @@ static int ofs_read(const char *path, char *buf, size_t size, off_t offset, stru
 	actual = wb->size - offset;
 	if (actual > size)
 		actual = size;
-	DEBUG("reading %s at %lld for %d (peek: %02x\n", path, offset, actual, wb->data[offset]);
+	DEBUG("reading %s at %" PRId64 " for %zu (peek: %02x\n", path, offset, actual, wb->data[offset]);
 	memcpy(buf, wb->data + offset, actual);
 
 	return actual;
@@ -625,7 +623,7 @@ static int ofs_write(const char *path, const char *buf, size_t size, off_t offse
 {
 	data_buffer_t *wb;
 	size_t newsize;
-	DEBUG("Writing %s at %lld for %d\n", path, offset, size);
+	DEBUG("Writing %s at %" PRId64 " for %zu\n", path, offset, size);
 	wb = (data_buffer_t *)fi->fh;
 
 	if (!wb)
@@ -645,7 +643,7 @@ static int ofs_write(const char *path, const char *buf, size_t size, off_t offse
 	wb->size = newsize;
 	wb->write_mode = 1;
 
-	DEBUG("memcpy to %p (%p) from %p cnt %d\n", wb->data + offset, wb->data, buf, size);
+	DEBUG("memcpy to %p (%p) from %p cnt %zu\n", wb->data + offset, wb->data, buf, size);
 	(void) memcpy(&wb->data[offset], buf, size);
 
 	return size;
@@ -662,7 +660,7 @@ static int ofs_release(const char *path, struct fuse_file_info *fi)
 	wb = (data_buffer_t *)fi->fh;
 	DEBUG("Releasing: %s (%p)\n", path, wb);
 	if (wb && wb->data && wb->write_mode) {
-		DEBUG("Now writing %s for %d (%02x)\n", path, wb->size, wb->data[0]);
+		DEBUG("Now writing %s for %zu (%02x)\n", path, wb->size, wb->data[0]);
 
 	        conn = ofs_find_connection(path, &filepath);
 		if (!conn)
@@ -683,11 +681,11 @@ static int ofs_release(const char *path, struct fuse_file_info *fi)
 	return 0;
 }
 
+#ifdef SIEMENS
 /* just sum all clients */
 static int ofs_statfs(const char *UNUSED(label), struct statfs *st)
 {
 	connection_t *conn;
-	int res;
 	int size = 0, free = 0;
 
         for (conn = connections; conn; conn = conn->next)
@@ -723,6 +721,7 @@ static int ofs_statfs(const char *UNUSED(label), struct statfs *st)
 
 	return 0;
 }
+#endif
 
 static void *ofs_init(void) {
 
@@ -736,7 +735,7 @@ static void *ofs_init(void) {
 	return NULL;
 }
 
-static void ofs_destroy(void *private_data) {
+static void ofs_destroy(void *UNUSED(private_data)) {
 	connection_t *conn;
 	
 	DEBUG("terminating...\n");
@@ -774,7 +773,9 @@ static struct fuse_operations ofs_oper = {
 	open:		ofs_open,
 	read:		ofs_read,
 	write:		ofs_write,
+#ifdef SIEMENS
 	statfs:		ofs_statfs,
+#endif
 	release:	ofs_release,
 	flush:		NULL,
 	fsync:		NULL,
@@ -784,8 +785,6 @@ static struct fuse_operations ofs_oper = {
 
 int main(int argc, char *argv[])
 {
-	int res;
-	
 	while (1) {
 		int option_index = 0;
 		int c;
